/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence;

import com.topcoder.document.index.persistence.impl.PersistenceConfigurationException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Tests functionality of custom exceptions. All consturctors are tested.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ExceptionTestCase extends TestCase {
    /**
     * Represents a throwable cause.
     */
    private static final Exception CAUSE = new Exception();

    /**
     * Represents a string with a detail message.
     */
    private static final String DETAIL_MESSAGE = "detail";

    /**
     * Aggragates all tests in this class.
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(ExceptionTestCase.class);
    }

    /**
     * Tests accuracy of <code>PersistenceConfigurationException(String)</code> constructor. The detail error message
     * should be correct.
     */
    public void testPersistenceConfigurationExceptionStringAccuracy() {
        // Construct PersistenceConfigurationException with a detail message
        PersistenceConfigurationException exception = new PersistenceConfigurationException(DETAIL_MESSAGE);

        // Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * Tests accuracy of <code>PersistenceConfigurationException(String, Throwable)</code> constructor. The detail
     * error message and the original cause of error should be correct.
     */
    public void testPersistenceConfigurationExceptionStringThrowableAccuracy() {
        // Construct PersistenceConfigurationException with a detail message and a cause
        PersistenceConfigurationException exception = new PersistenceConfigurationException(DETAIL_MESSAGE, CAUSE);

        // Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE + ", caused by null",
            exception.getMessage());

        // Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }
}








